@@ -19,6 +19,7 @@ from tkinter import ttk
 from tkinter import filedialog
 from tkinter import messagebox
 import os
+import subprocess
 import string
 import numpy as np
 
@@ -32,6 +33,9 @@ import tdt
 import xlsxwriter as xl
 from pathlib import Path
 
+import io
+from contextlib import redirect_stdout
+
 from trompy import *
 
 # Main class for GUI
@@ -48,16 +52,20 @@ class Window_photo(Frame):
         ttk.Frame.__init__(self, master, style='TFrame', padding=(10, 10, 15, 15))               
         
         self.master = master
-        self.quickstart = quickstart        
+        self.quickstart = quickstart     
+        self.startdir = Path(os.getcwd())
         self.init_window()
+        
+        self.master.bind_all("<Return>", self.callback)
 
     def init_window(self):
         self.master.title('Photometry Analyzer')
         self.pack(fill=BOTH, expand=1)
-        
+
         #Frames for session window and snipits
         self.f2 = ttk.Frame(self, style='inner.TFrame', relief='sunken',
                             borderwidth=5, height=150)
+        # self.f2.bind("<Return>", self.callback())
         self.f3 = ttk.Frame(self, style='inner.TFrame', relief='sunken',
                             borderwidth=5, height=150)
         self.f4 = ttk.Frame(self, style='inner.TFrame', relief='sunken',
@@ -66,20 +74,26 @@ class Window_photo(Frame):
                             borderwidth=5, height=200, width=200)
         self.f6 = ttk.Frame(self, style='inner.TFrame', relief='sunken',
                             borderwidth=5, height=200, width=200)
+        
+        # self.f7 = ScrollableFrame(self)
+        self.terminal = Text(self, bg='black', fg='white')
+        self.terminal.insert(INSERT, "Photometry Analyzer 3.0")
+        self.terminal.grid(column=0, row=16, columnspan=10, sticky=(N,S,E,W))
 
         # Button definitions
         self.choosefileBtn = ttk.Button(self, text='Choose Tank', command=self.choosefile)
         self.loaddataBtn = ttk.Button(self, text='Load data', command=self.loaddata)
         self.makelickrunsBtn = ttk.Button(self, text='Lick runs', command=self.makelickruns)
-        self.makesnipsBtn = ttk.Button(self, text='Make Snips', command=self.makesnips)
-        self.noiseBtn = ttk.Button(self, text='Turn noise off', command=self.togglenoise)
+        self.makesnipsBtn = ttk.Button(self, text='Make Snips', command=self.refresh)
+        self.noiseBtn = ttk.Button(self, text='Toggle noise', command=self.togglenoise)
         self.prevtrialBtn = ttk.Button(self, text='Prev Trial', command=self.prevtrial)
         self.nexttrialBtn = ttk.Button(self, text='Next Trial', command=self.nexttrial)
         self.showallBtn = ttk.Button(self, text='Show All', command=self.showall)
-        self.refreshBtn = ttk.Button(self, text='Refresh', command=self.makesnips)
+        self.refreshBtn = ttk.Button(self, text='Refresh', command=self.refresh)
         self.defaultfolderBtn = ttk.Button(self, text='Default folder', command=self.chooseexportfolder)
         self.makeexcelBtn = ttk.Button(self, text='Make Excel', command=self.makeExcel)
         self.savefigsBtn = ttk.Button(self, text='Save Figs', command=self.savefigs)
+        self.toggletipsBtn = ttk.Button(self, text='Toggle tips', command=self.toggletips)
 
         # Label definitions
         self.shortfilename = StringVar(self.master)
@@ -126,7 +140,6 @@ class Window_photo(Frame):
 
         self.aboutLbl = ttk.Label(self, text='Photometry Analyzer-3.0 by J McCutcheon')
 
-        
         # Packing grid with widgets
         self.f2.grid(column=2, row=0, columnspan=3, rowspan=5, sticky=(N,S,E,W))
         self.f3.grid(column=5, row=0, columnspan=3, rowspan=5, sticky=(N,S,E,W))
@@ -139,6 +152,8 @@ class Window_photo(Frame):
         self.filenameLbl.grid(column=0, row=4, rowspan=2, sticky=(E,W))
         self.timelockLbl.grid(column=0, row=4, rowspan=2, sticky=(E,W))
         
+        self.toggletipsBtn.grid(column=9, row=0)
+        
         self.primarysigLbl.grid(column=1, row=0)
         self.autofsigLbl.grid(column=1, row=2)
         
@@ -183,12 +198,23 @@ class Window_photo(Frame):
         self.updateeventoptions()
         
         self.sessionviewer()
-        
+
         if self.quickstart:
-            alert('Welcome to the photometry analyzer! First click "Choose tank" to select a tank to analyze')
+            tips('Welcome to the photometry analyzer! First click "Choose tank" to select a tank to analyze')
         
+    def callback(self, *args):
+
+        if hasattr(self, 'data'):
+            try:
+                self.refresh()
+            except: pass
+        
+    def refresh(self):
+        self.getoutput(self.makesnips)
+    
     def choosefile(self):
-        self.tdtfile = filedialog.askdirectory(initialdir=os.getcwd(), title='Select a tank.')
+        self.tdtfile = Path(filedialog.askdirectory(initialdir=self.startdir, title='Select a tank.'))
+        self.startdir = self.tdtfile.parent
         self.shortfilename.set(ntpath.dirname(self.tdtfile))
         
         print(self.shortfilename.get())
@@ -200,7 +226,7 @@ class Window_photo(Frame):
         self.updateeventoptions()
         
         if self.quickstart:
-            alert('Great! Now select the correct values for your primary signal and autofluorescence signal. Then press "Load data"')
+            tips('Great! Now select the correct values for your primary signal and autofluorescence signal. Then press "Load data"')
     
     def getstreamandepochnames(self):
         tmp = tdt.read_block(self.tdtfile, t2=2, evtype=['streams'])
@@ -244,9 +270,12 @@ class Window_photo(Frame):
     def loaddata(self):   
         self.progress['value'] = 0
         
+        self.addtoterminal("\nLoading streams...\n")
+        
         self.progress['value'] = 40
         # load in streams
-        self.loadstreams()
+        self.getoutput(self.loadstreams)
+
         self.progress['value'] = 60
         
         # process data
@@ -262,7 +291,7 @@ class Window_photo(Frame):
         self.progress['value'] = 100
         
         if self.quickstart:
-            alert('Super! Now you can pick a event to timelock your snips to - yuo can choose whether you want onset or offset, remove other events in the baseline, or even just make a series of random events. Once selected, click "Make snips"')
+            tips('Super! Now you can pick a event to timelock your snips to - yuo can choose whether you want onset or offset, remove other events in the baseline, or even just make a series of random events. Once selected, click "Make snips"')
             self.number_of_times = 0
             
     def loadstreams(self):
@@ -328,6 +357,7 @@ class Window_photo(Frame):
 
     def makesnips(self):
         # get events and number of bins from dropdown menus
+        print("Making and plotting snips...")
         self.setevents()
         
         # extract snips and calculate noise from data      
@@ -358,16 +388,16 @@ class Window_photo(Frame):
         
         if self.quickstart:
             if self.number_of_times == 0:
-                alert('You can turn noise on and off with the "Toggle noise" button.')
+                tips('You can turn noise on and off with the "Toggle noise" button.')
                 self.number_of_times = 1
             elif self.number_of_times == 1:
-                alert('You can alter the baseline, snip length, sample frequency, and noise threshold by using the fields on the right.')
+                tips('You can alter the baseline, snip length, sample frequency, and noise threshold by using the fields on the left.')
                 self.number_of_times = 2
             elif self.number_of_times == 2:
-                alert('You can export these data using the various Export / Save figs options at the bottom.')
+                tips('You can export these data using the various Export / Save figs options at the bottom.')
                 self.number_of_times = 3
             elif self.number_of_times == 3:
-                alert('OK. Got it? Play around with the GUI as you see fit and if you notice bugs or would like added features let me know [j.mccutcheon@uit.no]')
+                tips('OK. Got it? Play around with the GUI as you see fit and if you notice bugs or would like added features let me know [j.mccutcheon@uit.no]')
                 self.number_of_times = 4
     def setevents(self):
         try:
@@ -423,14 +453,26 @@ class Window_photo(Frame):
     def togglenoise(self):
         if self.noise:
             self.noise = False
-            self.noiseBtn.config(text="Turn noise on")
+            self.noiseBtn.config(text="Toggle noise")
+            self.noiseBtn.state(['pressed'])
+            self.addtoterminal(f"Noise set with threshold of {self.noisethField.get()} and noisy trials removed.\n")
         else:
             self.noise = True
-            self.noiseBtn.config(text="Turn noise off")
+            self.noiseBtn.config(text="Toggle noise")
+            self.noiseBtn.state(['!pressed'])
+            self.addtoterminal("Noisy trials included.\n")
             
         try:
-            self.makesnips()
+            self.refresh()
         except: pass
+    
+    def toggletips(self):
+        if self.quickstart:
+            self.quickstart = False
+            self.toggletipsBtn.state(['!pressed'])
+        else:
+            self.quickstart = True
+            self.toggletipsBtn.state(['pressed'])
         
     def prevtrial(self):
         try:
@@ -440,7 +482,8 @@ class Window_photo(Frame):
                 self.currenttrial.set(str(int(self.currenttrial.get()) - 1))
         except ValueError:
             self.currenttrial.set(str(self.maxtrials))
-        self.makesnips()
+        self.addtoterminal(f"Showing trial {self.currenttrial.get()}.\n")
+        self.refresh()
         
     def nexttrial(self):
         try:
@@ -449,13 +492,14 @@ class Window_photo(Frame):
             self.currenttrial.set(str(int(self.currenttrial.get()) + 1))
         except ValueError:
             self.currenttrial.set(str(1))
-        self.makesnips()
+        self.addtoterminal(f"Showing trial {self.currenttrial.get()}.\n")
+        self.refresh()
         
     def showall(self):
-        print('Showing all trials')
+        self.addtoterminal('Showing all trials.\n')
         self.trial_to_plot = 'all'
         self.currenttrial.set('')
-        self.makesnips()
+        self.refresh()
 
     def makelickruns(self):
         self.setlicks()
@@ -540,6 +584,8 @@ class Window_photo(Frame):
         savexlfile = self.savefolder / f"output{self.fileinfo}.xlsx"
         
         print('File saved as', savexlfile)
+        
+        self.terminal.insert(END, f'File saved as {savexlfile}')
 
         self.makesummarysheet()
 
@@ -595,15 +641,34 @@ class Window_photo(Frame):
         self.f_trials.savefig(self.savefolder / f"trials{self.fileinfo}.pdf")
         self.f_heatmap.savefig(self.savefolder / f"heatmap{self.fileinfo}.pdf")
         self.f_avgsnips.savefig(self.savefolder / f"averagesnips{self.fileinfo}.pdf")
+        
+        self.terminal.insert(END, f"Saving figures in {self.savefolder}")
+        
+    def addtoterminal(self, s):
+        self.terminal.insert(END, s)
+        self.terminal.see(END)
+        print(s)
+
+    def getoutput(self, function):
+        f = io.StringIO()
+        with redirect_stdout(f):
+            function()
+        s = f.getvalue()
+        self.addtoterminal(s)
 
 def start_photo_gui(quickstart=False):
     root = Tk()
     app = Window_photo(root, quickstart)
+
     root.lift()
     root.mainloop()
+    
+def tips(msg):
+    print(msg)
+    messagebox.showinfo('Quick Tips', msg)
 
 if __name__ == '__main__':
     os.chdir("C:\\Github\\PPP_analysis\\data\\Eelke-171027-111329\\")
     os.chdir("C:\\Test Data\\data\\FiPho-180416\\")
-    start_photo_gui(quickstart=True)
+    start_photo_gui(quickstart=False)
     
\ No newline at end of file
